#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsonpointer
version:              1.5.0
visibility:           public
id:                   hjsonpointer-1.5.0-5G7ZMAQOjfs5eQRWao501h
key:                  hjsonpointer-1.5.0-5G7ZMAQOjfs5eQRWao501h
license:              MIT
maintainer:           ian@housejeffries.com
author:               Ian Grant Jeffries
homepage:             https://github.com/seagreen/hjsonpointer
synopsis:             JSON Pointer library
category:             Data
abi:                  0072f9af360ef8d40c819475a44e248c
exposed:              True
exposed-modules:      JSONPointer
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hjsonpointer-1.5.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hjsonpointer-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hjsonpointer-1.5.0
hs-libraries:         HShjsonpointer-1.5.0-5G7ZMAQOjfs5eQRWao501h
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE text-1.2.4.1
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock

haddock-html:         /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

